@@ -1,4 +1,4 @@
-from os.path import join, dirname
+from os.path import dirname, join
 
 
 class Invoice(dict):
