@@ -1,10 +1,11 @@
 
-from os.path import abspath, join, dirname
-from relatorio import Report
+from os.path import abspath, dirname, join
 
 # test data
 from common import inv
 
+from relatorio import Report
+
 # PDF
 if __name__ == '__main__':
     print("generating output_basic.pdf... ", end='')
