@@ -9,8 +9,8 @@ easy: you just have to create a plugin for this.
 relatorio also provides a report repository allowing you to link python objects
 and report together, find reports by mimetypes/name/python objects.
 """
-from .reporting import MIMETemplateLoader, ReportRepository, Report
 from . import templates
+from .reporting import MIMETemplateLoader, Report, ReportRepository
 
-__version__ = '0.10.0'
+__version__ = '0.10.1'
 __all__ = ['MIMETemplateLoader', 'ReportRepository', 'Report', 'templates']
